# Example Package

### Contents
This module help you to replace null value with mean, mode or median of that specific feature.

```sh
  from replace_null import ReplaceNull
  ReplaceNull.replace_by_mean(data_frame)
  ```
###### Note:
    This is only for numeric features.